.smiles-drawer-container.border {
    border: 1px solid #888;
    border-bottom: 0;
}

.smiles-drawer-container.border:first-child {
    border-radius: 5px 5px 0 0;
}

.smiles-drawer-container.border:last-child {
    border-bottom: 1px solid #888;
    border-radius: 0 0 5px 5px;
}

.smiles-drawer-title {
    padding: 5px;
    font-family: Arial, Helvetica, sans-serif;
    font-size: 0.9em;
    border-bottom: 1px solid #888;
}

.smiles-drawer-title:after {
    content: " 🠗";
}

.smiles-drawer-element {
    padding: 5px;
}