define((()=>(()=>{var e={758:(e,n,o)=>{o.p=document.querySelector("body").getAttribute("data-base-url")+"nbextensions/faerun-notebook",window.require&&window.require.config({map:{"*":{"faerun-notebook":"nbextensions/faerun-notebook/index"}}}),e.exports={load_ipython_extension:function(){}}}},n={};function o(r){var t=n[r];if(void 0!==t)return t.exports;var i=n[r]={exports:{}};return e[r](i,i.exports,o),i.exports}return o.p="",o(758)})()));