#hover-indicator {
    display: none;
    position: absolute;
    z-index: 999;
    border: 1px solid #fff;
    background-color: rgba(255, 255, 255, 0.25);
    border-radius: 50%;
    pointer-events: none;
}

#hover-indicator.show {
    display: block !important
}

.selected-indicator {
    position: absolute;
    z-index: 999;
    pointer-events: none;
}

.selected-indicator .crosshair-x {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    height: 2px;
    width: 100%;
    margin: auto;
    background-color: #fff;
}

.selected-indicator .crosshair-y {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    width: 2px;
    height: 100%;
    margin: auto;
    background-color: #fff;
}